Class: Google::Apis::SecuresourcemanagerV1::CloseIssueRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securesourcemanager_v1/classes.rb,
lib/google/apis/securesourcemanager_v1/representations.rb,
lib/google/apis/securesourcemanager_v1/representations.rb

Overview

The request to close an issue.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloseIssueRequest

Returns a new instance of CloseIssueRequest.



407
408
409
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 407

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Optional. The current etag of the issue. If the etag is provided and does not match the current etag of the issue, closing will be blocked and an ABORTED error will be returned. Corresponds to the JSON property etag

Returns:

  • (String)


405
406
407
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 405

def etag
  @etag
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



412
413
414
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 412

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
end