Class: Google::Apis::SecuresourcemanagerV1::FetchTreeResponse
- Inherits:
-
Object
- Object
- Google::Apis::SecuresourcemanagerV1::FetchTreeResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securesourcemanager_v1/classes.rb,
lib/google/apis/securesourcemanager_v1/representations.rb,
lib/google/apis/securesourcemanager_v1/representations.rb
Overview
Response message containing a list of TreeEntry objects.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#tree_entries ⇒ Array<Google::Apis::SecuresourcemanagerV1::TreeEntry>
The list of TreeEntry objects.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FetchTreeResponse
constructor
A new instance of FetchTreeResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FetchTreeResponse
Returns a new instance of FetchTreeResponse.
637 638 639 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 637 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
630 631 632 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 630 def next_page_token @next_page_token end |
#tree_entries ⇒ Array<Google::Apis::SecuresourcemanagerV1::TreeEntry>
The list of TreeEntry objects.
Corresponds to the JSON property treeEntries
635 636 637 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 635 def tree_entries @tree_entries end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
642 643 644 645 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 642 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @tree_entries = args[:tree_entries] if args.key?(:tree_entries) end |