Class: Google::Apis::SecuresourcemanagerV1::Instance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securesourcemanager_v1/classes.rb,
lib/google/apis/securesourcemanager_v1/representations.rb,
lib/google/apis/securesourcemanager_v1/representations.rb

Overview

A resource that represents a Secure Source Manager instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Instance

Returns a new instance of Instance.



1002
1003
1004
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1002

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Create timestamp. Corresponds to the JSON property createTime

Returns:

  • (String)


946
947
948
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 946

def create_time
  @create_time
end

#host_configGoogle::Apis::SecuresourcemanagerV1::HostConfig

HostConfig has different instance endpoints. Corresponds to the JSON property hostConfig



951
952
953
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 951

def host_config
  @host_config
end

#kms_keyString

Optional. Immutable. Customer-managed encryption key name, in the format projects//locations//keyRings//cryptoKeys/. Corresponds to the JSON property kmsKey

Returns:

  • (String)


957
958
959
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 957

def kms_key
  @kms_key
end

#labelsHash<String,String>

Optional. Labels as key value pairs. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


962
963
964
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 962

def labels
  @labels
end

#nameString

Optional. A unique identifier for an instance. The name should be of the format: projects/project_number/locations/location_id/instances/ instance_id`project_number: Maps to a unique int64 id assigned to each project.location_id: Refers to the region where the instance will be deployed. Since Secure Source Manager is a regional service, it must be one of the valid GCP regions.instance_id: User provided name for the instance, must be unique for a project_number and location_id combination. Corresponds to the JSON propertyname`

Returns:

  • (String)


973
974
975
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 973

def name
  @name
end

#private_configGoogle::Apis::SecuresourcemanagerV1::PrivateConfig

PrivateConfig includes settings for private instance. Corresponds to the JSON property privateConfig



978
979
980
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 978

def private_config
  @private_config
end

#stateString

Output only. Current state of the instance. Corresponds to the JSON property state

Returns:

  • (String)


983
984
985
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 983

def state
  @state
end

#state_noteString

Output only. An optional field providing information about the current instance state. Corresponds to the JSON property stateNote

Returns:

  • (String)


989
990
991
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 989

def state_note
  @state_note
end

#update_timeString

Output only. Update timestamp. Corresponds to the JSON property updateTime

Returns:

  • (String)


994
995
996
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 994

def update_time
  @update_time
end

#workforce_identity_federation_configGoogle::Apis::SecuresourcemanagerV1::WorkforceIdentityFederationConfig

WorkforceIdentityFederationConfig allows this instance to support users from external identity providers. Corresponds to the JSON property workforceIdentityFederationConfig



1000
1001
1002
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1000

def workforce_identity_federation_config
  @workforce_identity_federation_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1007

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @host_config = args[:host_config] if args.key?(:host_config)
  @kms_key = args[:kms_key] if args.key?(:kms_key)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @private_config = args[:private_config] if args.key?(:private_config)
  @state = args[:state] if args.key?(:state)
  @state_note = args[:state_note] if args.key?(:state_note)
  @update_time = args[:update_time] if args.key?(:update_time)
  @workforce_identity_federation_config = args[:workforce_identity_federation_config] if args.key?(:workforce_identity_federation_config)
end