Class: Google::Apis::SecuresourcemanagerV1::ListBranchRulesResponse
- Inherits:
-
Object
- Object
- Google::Apis::SecuresourcemanagerV1::ListBranchRulesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securesourcemanager_v1/classes.rb,
lib/google/apis/securesourcemanager_v1/representations.rb,
lib/google/apis/securesourcemanager_v1/representations.rb
Overview
ListBranchRulesResponse is the response to listing branchRules.
Instance Attribute Summary collapse
-
#branch_rules ⇒ Array<Google::Apis::SecuresourcemanagerV1::BranchRule>
The list of branch rules.
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListBranchRulesResponse
constructor
A new instance of ListBranchRulesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListBranchRulesResponse
Returns a new instance of ListBranchRulesResponse.
1139 1140 1141 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1139 def initialize(**args) update!(**args) end |
Instance Attribute Details
#branch_rules ⇒ Array<Google::Apis::SecuresourcemanagerV1::BranchRule>
The list of branch rules.
Corresponds to the JSON property branchRules
1132 1133 1134 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1132 def branch_rules @branch_rules end |
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
1137 1138 1139 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1137 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1144 1145 1146 1147 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1144 def update!(**args) @branch_rules = args[:branch_rules] if args.key?(:branch_rules) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |