Class: Google::Apis::SecuresourcemanagerV1::ListHooksResponse
- Inherits:
-
Object
- Object
- Google::Apis::SecuresourcemanagerV1::ListHooksResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securesourcemanager_v1/classes.rb,
lib/google/apis/securesourcemanager_v1/representations.rb,
lib/google/apis/securesourcemanager_v1/representations.rb
Overview
ListHooksResponse is response to list hooks.
Instance Attribute Summary collapse
-
#hooks ⇒ Array<Google::Apis::SecuresourcemanagerV1::Hook>
The list of hooks.
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListHooksResponse
constructor
A new instance of ListHooksResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListHooksResponse
Returns a new instance of ListHooksResponse.
1164 1165 1166 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1164 def initialize(**args) update!(**args) end |
Instance Attribute Details
#hooks ⇒ Array<Google::Apis::SecuresourcemanagerV1::Hook>
The list of hooks.
Corresponds to the JSON property hooks
1157 1158 1159 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1157 def hooks @hooks end |
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
1162 1163 1164 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1162 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1169 1170 1171 1172 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1169 def update!(**args) @hooks = args[:hooks] if args.key?(:hooks) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |