Class: Google::Apis::SecuresourcemanagerV1::ListIssueCommentsResponse
- Inherits:
-
Object
- Object
- Google::Apis::SecuresourcemanagerV1::ListIssueCommentsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securesourcemanager_v1/classes.rb,
lib/google/apis/securesourcemanager_v1/representations.rb,
lib/google/apis/securesourcemanager_v1/representations.rb
Overview
The response to list issue comments.
Instance Attribute Summary collapse
-
#issue_comments ⇒ Array<Google::Apis::SecuresourcemanagerV1::IssueComment>
The list of issue comments.
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListIssueCommentsResponse
constructor
A new instance of ListIssueCommentsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListIssueCommentsResponse
Returns a new instance of ListIssueCommentsResponse.
1220 1221 1222 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1220 def initialize(**args) update!(**args) end |
Instance Attribute Details
#issue_comments ⇒ Array<Google::Apis::SecuresourcemanagerV1::IssueComment>
The list of issue comments.
Corresponds to the JSON property issueComments
1213 1214 1215 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1213 def issue_comments @issue_comments end |
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
1218 1219 1220 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1218 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1225 1226 1227 1228 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1225 def update!(**args) @issue_comments = args[:issue_comments] if args.key?(:issue_comments) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |