Class: Google::Apis::SecuresourcemanagerV1::ListPullRequestFileDiffsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securesourcemanager_v1/classes.rb,
lib/google/apis/securesourcemanager_v1/representations.rb,
lib/google/apis/securesourcemanager_v1/representations.rb

Overview

ListPullRequestFileDiffsResponse is the response containing file diffs returned from ListPullRequestFileDiffs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListPullRequestFileDiffsResponse

Returns a new instance of ListPullRequestFileDiffsResponse.



1347
1348
1349
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1347

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_diffsArray<Google::Apis::SecuresourcemanagerV1::FileDiff>

The list of pull request file diffs. Corresponds to the JSON property fileDiffs



1340
1341
1342
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1340

def file_diffs
  @file_diffs
end

#next_page_tokenString

A token identifying a page of results the server should return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1345
1346
1347
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1345

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1352
1353
1354
1355
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1352

def update!(**args)
  @file_diffs = args[:file_diffs] if args.key?(:file_diffs)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end