Class: Google::Apis::SecuresourcemanagerV1::ListPullRequestsResponse
- Inherits:
-
Object
- Object
- Google::Apis::SecuresourcemanagerV1::ListPullRequestsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securesourcemanager_v1/classes.rb,
lib/google/apis/securesourcemanager_v1/representations.rb,
lib/google/apis/securesourcemanager_v1/representations.rb
Overview
ListPullRequestsResponse is the response to list pull requests.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#pull_requests ⇒ Array<Google::Apis::SecuresourcemanagerV1::PullRequest>
The list of pull requests.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListPullRequestsResponse
constructor
A new instance of ListPullRequestsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListPullRequestsResponse
Returns a new instance of ListPullRequestsResponse.
1372 1373 1374 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1372 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
1365 1366 1367 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1365 def next_page_token @next_page_token end |
#pull_requests ⇒ Array<Google::Apis::SecuresourcemanagerV1::PullRequest>
The list of pull requests.
Corresponds to the JSON property pullRequests
1370 1371 1372 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1370 def pull_requests @pull_requests end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1377 1378 1379 1380 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1377 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @pull_requests = args[:pull_requests] if args.key?(:pull_requests) end |