Class: Google::Apis::SecuresourcemanagerV1::OpenIssueRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securesourcemanager_v1/classes.rb,
lib/google/apis/securesourcemanager_v1/representations.rb,
lib/google/apis/securesourcemanager_v1/representations.rb

Overview

The request to open an issue.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OpenIssueRequest

Returns a new instance of OpenIssueRequest.



1479
1480
1481
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1479

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Optional. The current etag of the issue. If the etag is provided and does not match the current etag of the issue, opening will be blocked and an ABORTED error will be returned. Corresponds to the JSON property etag

Returns:

  • (String)


1477
1478
1479
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1477

def etag
  @etag
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1484
1485
1486
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1484

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
end