Class: Google::Apis::SecuresourcemanagerV1::Repository

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securesourcemanager_v1/classes.rb,
lib/google/apis/securesourcemanager_v1/representations.rb,
lib/google/apis/securesourcemanager_v1/representations.rb

Overview

Metadata of a Secure Source Manager repository.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Repository

Returns a new instance of Repository.



1995
1996
1997
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1995

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Create timestamp. Corresponds to the JSON property createTime

Returns:

  • (String)


1945
1946
1947
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1945

def create_time
  @create_time
end

#descriptionString

Optional. Description of the repository, which cannot exceed 500 characters. Corresponds to the JSON property description

Returns:

  • (String)


1950
1951
1952
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1950

def description
  @description
end

#etagString

Optional. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


1957
1958
1959
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1957

def etag
  @etag
end

#initial_configGoogle::Apis::SecuresourcemanagerV1::InitialConfig

Repository initialization configuration. Corresponds to the JSON property initialConfig



1962
1963
1964
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1962

def initial_config
  @initial_config
end

#instanceString

Optional. The name of the instance in which the repository is hosted, formatted as projects/project_number/locations/location_id/instances/ instance_id`When creating repository via securesourcemanager.googleapis.com, this field is used as input. When creating repository via *.sourcemanager.dev, this field is output only. Corresponds to the JSON propertyinstance`

Returns:

  • (String)


1971
1972
1973
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1971

def instance
  @instance
end

#nameString

Optional. A unique identifier for a repository. The name should be of the format: projects/project/locations/location_id/repositories/ repository_id` Corresponds to the JSON propertyname`

Returns:

  • (String)


1978
1979
1980
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1978

def name
  @name
end

#uidString

Output only. Unique identifier of the repository. Corresponds to the JSON property uid

Returns:

  • (String)


1983
1984
1985
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1983

def uid
  @uid
end

#update_timeString

Output only. Update timestamp. Corresponds to the JSON property updateTime

Returns:

  • (String)


1988
1989
1990
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1988

def update_time
  @update_time
end

#urisGoogle::Apis::SecuresourcemanagerV1::UrIs

URIs for the repository. Corresponds to the JSON property uris



1993
1994
1995
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1993

def uris
  @uris
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2000
2001
2002
2003
2004
2005
2006
2007
2008
2009
2010
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 2000

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @initial_config = args[:initial_config] if args.key?(:initial_config)
  @instance = args[:instance] if args.key?(:instance)
  @name = args[:name] if args.key?(:name)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @uris = args[:uris] if args.key?(:uris)
end