Module: Google::Apis::SecuresourcemanagerV1
- Defined in:
- lib/google/apis/securesourcemanager_v1.rb,
lib/google/apis/securesourcemanager_v1/classes.rb,
lib/google/apis/securesourcemanager_v1/service.rb,
lib/google/apis/securesourcemanager_v1/gem_version.rb,
lib/google/apis/securesourcemanager_v1/representations.rb
Overview
Secure Source Manager API
Regionally deployed, single-tenant managed source code repository hosted on Google Cloud.
Defined Under Namespace
Classes: AuditConfig, AuditLogConfig, BatchCreatePullRequestCommentsRequest, Binding, Branch, BranchRule, CancelOperationRequest, Check, CloseIssueRequest, ClosePullRequestRequest, Code, Comment, CreatePullRequestCommentRequest, Empty, Expr, FetchBlobResponse, FetchTreeResponse, FileDiff, Hook, HostConfig, InitialConfig, Instance, Issue, IssueComment, ListBranchRulesResponse, ListHooksResponse, ListInstancesResponse, ListIssueCommentsResponse, ListIssuesResponse, ListLocationsResponse, ListOperationsResponse, ListPullRequestCommentsResponse, ListPullRequestFileDiffsResponse, ListPullRequestsResponse, ListRepositoriesResponse, Location, MergePullRequestRequest, OpenIssueRequest, OpenPullRequestRequest, Operation, OperationMetadata, Policy, Position, PrivateConfig, PullRequest, PullRequestComment, PushOption, Repository, ResolvePullRequestCommentsRequest, Review, SecureSourceManagerService, SetIamPolicyRequest, Status, TestIamPermissionsRequest, TestIamPermissionsResponse, TreeEntry, UnresolvePullRequestCommentsRequest, UrIs, WorkforceIdentityFederationConfig
Constant Summary collapse
- GEM_VERSION =
Version of the google-apis-securesourcemanager_v1 gem
"0.2.0"- GENERATOR_VERSION =
Version of the code generator used to generate this client
"0.19.0"- REVISION =
Revision of the discovery document this client was generated from
"0"- VERSION =
Version of the Secure Source Manager API this client connects to. This is NOT the gem version.
'V1'- AUTH_CLOUD_PLATFORM =
See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.
'https://www.googleapis.com/auth/cloud-platform'