Class: Google::Apis::SecuresourcemanagerV1::Code
- Inherits:
-
Object
- Object
- Google::Apis::SecuresourcemanagerV1::Code
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securesourcemanager_v1/classes.rb,
lib/google/apis/securesourcemanager_v1/representations.rb,
lib/google/apis/securesourcemanager_v1/representations.rb
Overview
The comment on a code line.
Instance Attribute Summary collapse
-
#body ⇒ String
Required.
-
#effective_commit_sha ⇒ String
Output only.
-
#effective_root_comment ⇒ String
Output only.
-
#position ⇒ Google::Apis::SecuresourcemanagerV1::Position
The position of the code comment.
-
#reply ⇒ String
Optional.
-
#resolved ⇒ Boolean
(also: #resolved?)
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Code
constructor
A new instance of Code.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Code
Returns a new instance of Code.
467 468 469 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 467 def initialize(**args) update!(**args) end |
Instance Attribute Details
#body ⇒ String
Required. The comment body.
Corresponds to the JSON property body
437 438 439 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 437 def body @body end |
#effective_commit_sha ⇒ String
Output only. The effective commit sha this code comment is pointing to.
Corresponds to the JSON property effectiveCommitSha
442 443 444 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 442 def effective_commit_sha @effective_commit_sha end |
#effective_root_comment ⇒ String
Output only. The root comment of the conversation, derived from the reply
field.
Corresponds to the JSON property effectiveRootComment
448 449 450 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 448 def effective_root_comment @effective_root_comment end |
#position ⇒ Google::Apis::SecuresourcemanagerV1::Position
The position of the code comment.
Corresponds to the JSON property position
453 454 455 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 453 def position @position end |
#reply ⇒ String
Optional. Input only. The PullRequestComment resource name that this comment
is replying to.
Corresponds to the JSON property reply
459 460 461 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 459 def reply @reply end |
#resolved ⇒ Boolean Also known as: resolved?
Output only. Boolean indicator if the comment is resolved.
Corresponds to the JSON property resolved
464 465 466 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 464 def resolved @resolved end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
472 473 474 475 476 477 478 479 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 472 def update!(**args) @body = args[:body] if args.key?(:body) @effective_commit_sha = args[:effective_commit_sha] if args.key?(:effective_commit_sha) @effective_root_comment = args[:effective_root_comment] if args.key?(:effective_root_comment) @position = args[:position] if args.key?(:position) @reply = args[:reply] if args.key?(:reply) @resolved = args[:resolved] if args.key?(:resolved) end |