Class: Google::Apis::SecuresourcemanagerV1::Issue
- Inherits:
-
Object
- Object
- Google::Apis::SecuresourcemanagerV1::Issue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securesourcemanager_v1/classes.rb,
lib/google/apis/securesourcemanager_v1/representations.rb,
lib/google/apis/securesourcemanager_v1/representations.rb
Overview
Metadata of an Issue.
Instance Attribute Summary collapse
-
#body ⇒ String
Optional.
-
#close_time ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#etag ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#state ⇒ String
Output only.
-
#title ⇒ String
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Issue
constructor
A new instance of Issue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Issue
Returns a new instance of Issue.
1069 1070 1071 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1069 def initialize(**args) update!(**args) end |
Instance Attribute Details
#body ⇒ String
Optional. Issue body. Provides a detailed description of the issue.
Corresponds to the JSON property body
1028 1029 1030 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1028 def body @body end |
#close_time ⇒ String
Output only. Close timestamp (if closed). Cleared when is re-opened.
Corresponds to the JSON property closeTime
1033 1034 1035 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1033 def close_time @close_time end |
#create_time ⇒ String
Output only. Creation timestamp.
Corresponds to the JSON property createTime
1038 1039 1040 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1038 def create_time @create_time end |
#etag ⇒ String
Optional. This checksum is computed by the server based on the value of other
fields, and may be sent on update and delete requests to ensure the client has
an up-to-date value before proceeding.
Corresponds to the JSON property etag
1045 1046 1047 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1045 def etag @etag end |
#name ⇒ String
Identifier. Unique identifier for an issue. The issue id is generated by the
server. Format: projects/project/locations/location/repositories/
repository/issues/issue_id`
Corresponds to the JSON propertyname`
1052 1053 1054 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1052 def name @name end |
#state ⇒ String
Output only. State of the issue.
Corresponds to the JSON property state
1057 1058 1059 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1057 def state @state end |
#title ⇒ String
Required. Issue title.
Corresponds to the JSON property title
1062 1063 1064 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1062 def title @title end |
#update_time ⇒ String
Output only. Last updated timestamp.
Corresponds to the JSON property updateTime
1067 1068 1069 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1067 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1074 def update!(**args) @body = args[:body] if args.key?(:body) @close_time = args[:close_time] if args.key?(:close_time) @create_time = args[:create_time] if args.key?(:create_time) @etag = args[:etag] if args.key?(:etag) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @title = args[:title] if args.key?(:title) @update_time = args[:update_time] if args.key?(:update_time) end |