Class: Google::Apis::SecuresourcemanagerV1::PrivateConfig
- Inherits:
-
Object
- Object
- Google::Apis::SecuresourcemanagerV1::PrivateConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securesourcemanager_v1/classes.rb,
lib/google/apis/securesourcemanager_v1/representations.rb,
lib/google/apis/securesourcemanager_v1/representations.rb
Overview
PrivateConfig includes settings for private instance.
Instance Attribute Summary collapse
-
#ca_pool ⇒ String
Optional.
-
#http_service_attachment ⇒ String
Output only.
-
#is_private ⇒ Boolean
(also: #is_private?)
Required.
-
#psc_allowed_projects ⇒ Array<String>
Optional.
-
#ssh_service_attachment ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PrivateConfig
constructor
A new instance of PrivateConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PrivateConfig
Returns a new instance of PrivateConfig.
1779 1780 1781 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1779 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ca_pool ⇒ String
Optional. Immutable. CA pool resource, resource must in the format of
projects/project/locations/location/caPools/ca_pool`.
Corresponds to the JSON propertycaPool`
1752 1753 1754 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1752 def ca_pool @ca_pool end |
#http_service_attachment ⇒ String
Output only. Service Attachment for HTTP, resource is in the format of
projects/project/regions/region/serviceAttachments/service_attachment`.
Corresponds to the JSON propertyhttpServiceAttachment`
1758 1759 1760 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1758 def @http_service_attachment end |
#is_private ⇒ Boolean Also known as: is_private?
Required. Immutable. Indicate if it's private instance.
Corresponds to the JSON property isPrivate
1763 1764 1765 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1763 def is_private @is_private end |
#psc_allowed_projects ⇒ Array<String>
Optional. Additional allowed projects for setting up PSC connections. Instance
host project is automatically allowed and does not need to be included in this
list.
Corresponds to the JSON property pscAllowedProjects
1771 1772 1773 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1771 def psc_allowed_projects @psc_allowed_projects end |
#ssh_service_attachment ⇒ String
Output only. Service Attachment for SSH, resource is in the format of
projects/project/regions/region/serviceAttachments/service_attachment`.
Corresponds to the JSON propertysshServiceAttachment`
1777 1778 1779 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1777 def @ssh_service_attachment end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1784 1785 1786 1787 1788 1789 1790 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 1784 def update!(**args) @ca_pool = args[:ca_pool] if args.key?(:ca_pool) @http_service_attachment = args[:http_service_attachment] if args.key?(:http_service_attachment) @is_private = args[:is_private] if args.key?(:is_private) @psc_allowed_projects = args[:psc_allowed_projects] if args.key?(:psc_allowed_projects) @ssh_service_attachment = args[:ssh_service_attachment] if args.key?(:ssh_service_attachment) end |