Class: Google::Apis::SecuresourcemanagerV1::ResolvePullRequestCommentsRequest
- Inherits:
-
Object
- Object
- Google::Apis::SecuresourcemanagerV1::ResolvePullRequestCommentsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securesourcemanager_v1/classes.rb,
lib/google/apis/securesourcemanager_v1/representations.rb,
lib/google/apis/securesourcemanager_v1/representations.rb
Overview
The request to resolve multiple pull request comments.
Instance Attribute Summary collapse
-
#auto_fill ⇒ Boolean
(also: #auto_fill?)
Optional.
-
#names ⇒ Array<String>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResolvePullRequestCommentsRequest
constructor
A new instance of ResolvePullRequestCommentsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResolvePullRequestCommentsRequest
Returns a new instance of ResolvePullRequestCommentsRequest.
2033 2034 2035 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 2033 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_fill ⇒ Boolean Also known as: auto_fill?
Optional. If set, at least one comment in a thread is required, rest of the
comments in the same thread will be automatically updated to resolved. If
unset, all comments in the same thread need be present.
Corresponds to the JSON property autoFill
2022 2023 2024 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 2022 def auto_fill @auto_fill end |
#names ⇒ Array<String>
Required. The names of the pull request comments to resolve. Format: projects/
project_number/locations/location_id/repositories/repository_id/
pullRequests/pull_request_id/pullRequestComments/comment_id`Only comments
from the same threads are allowed in the same request.
Corresponds to the JSON propertynames`
2031 2032 2033 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 2031 def names @names end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2038 2039 2040 2041 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 2038 def update!(**args) @auto_fill = args[:auto_fill] if args.key?(:auto_fill) @names = args[:names] if args.key?(:names) end |