Class: Google::Apis::SecuresourcemanagerV1::UnresolvePullRequestCommentsRequest
- Inherits:
-
Object
- Object
- Google::Apis::SecuresourcemanagerV1::UnresolvePullRequestCommentsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securesourcemanager_v1/classes.rb,
lib/google/apis/securesourcemanager_v1/representations.rb,
lib/google/apis/securesourcemanager_v1/representations.rb
Overview
The request to unresolve multiple pull request comments.
Instance Attribute Summary collapse
-
#auto_fill ⇒ Boolean
(also: #auto_fill?)
Optional.
-
#names ⇒ Array<String>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UnresolvePullRequestCommentsRequest
constructor
A new instance of UnresolvePullRequestCommentsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UnresolvePullRequestCommentsRequest
Returns a new instance of UnresolvePullRequestCommentsRequest.
2303 2304 2305 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 2303 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_fill ⇒ Boolean Also known as: auto_fill?
Optional. If set, at least one comment in a thread is required, rest of the
comments in the same thread will be automatically updated to unresolved. If
unset, all comments in the same thread need be present.
Corresponds to the JSON property autoFill
2292 2293 2294 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 2292 def auto_fill @auto_fill end |
#names ⇒ Array<String>
Required. The names of the pull request comments to unresolve. Format:
projects/project_number/locations/location_id/repositories/repository_id/
pullRequests/pull_request_id/pullRequestComments/comment_id`Only comments
from the same threads are allowed in the same request.
Corresponds to the JSON propertynames`
2301 2302 2303 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 2301 def names @names end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2308 2309 2310 2311 |
# File 'lib/google/apis/securesourcemanager_v1/classes.rb', line 2308 def update!(**args) @auto_fill = args[:auto_fill] if args.key?(:auto_fill) @names = args[:names] if args.key?(:names) end |